@@ -13,7 +13,7 @@ import numpy as np
 import zstandard as zstd
 
 
-__version__ = '0.2.0'
+__version__ = '0.2.3'
 
 
 @contextlib.contextmanager
@@ -105,8 +105,6 @@ class Context:
                 warnings.warn(f'Module "{mod.name}" is not an instance of Module', RuntimeWarning)
             self._modules.add(mod)
             for name in mod.output_names:
-                if name in self._producer:
-                    raise f'Producer for "{name}" is already registered'
                 self._producer[name] = mod
 
     def module(self, input, output):
@@ -145,10 +143,22 @@ class Context:
         path = self._get_path(name, run_hash)
         os.makedirs(os.path.dirname(path), exist_ok=True)
         if type(data) is np.ndarray:
-            np.savez_compressed(path + '.npz', data)
+            path = path + '.npz'
+            try:
+                np.savez_compressed(path, data)
+            except Exception as e:
+                if os.path.exists(path):
+                    os.remove(path)
+                raise e
         else:
-            with zstd_open_write(path + '.pickle.zst', level=19, threads=-1) as f:
-                pickle.dump(data, f, protocol=4)
+            path = path + '.pickle.zst'
+            try:
+                with zstd_open_write(path, level=19, threads=-1) as f:
+                    pickle.dump(data, f, protocol=4)
+            except Exception as e:
+                if os.path.exists(path):
+                    os.remove(path)
+                raise e
 
     def run(self, module, condition=None):
         if condition is None:
